Coverage report

File | function | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/indium/__init__.py | (no function) | 9 | 0 | 0 | 100%
src/indium/_confusables.py | (no function) | 2 | 0 | 0 | 100%
src/indium/_exceptions.py | InvalidTextError.__init__ | 2 | 0 | 0 | 100%
src/indium/_exceptions.py | (no function) | 7 | 0 | 0 | 100%
src/indium/_grapheme_data.py | (no function) | 21 | 0 | 0 | 100%
src/indium/_scripts_data.py | (no function) | 2 | 0 | 0 | 100%
src/indium/_unicode_data.py | is_invisible | 6 | 1 | 0 | 83%
src/indium/_unicode_data.py | is_combining | 3 | 1 | 0 | 67%
src/indium/_unicode_data.py | is_whitespace | 3 | 0 | 0 | 100%
src/indium/_unicode_data.py | get_unicode_name | 6 | 0 | 0 | 100%
src/indium/_unicode_data.py | get_category | 3 | 0 | 0 | 100%
src/indium/_unicode_data.py | (no function) | 9 | 0 | 0 | 100%
src/indium/invisibles.py | reveal | 17 | 0 | 0 | 100%
src/indium/invisibles.py | sanitize | 11 | 0 | 0 | 100%
src/indium/invisibles.py | detect_invisibles | 6 | 0 | 0 | 100%
src/indium/invisibles.py | count_by_category | 5 | 0 | 0 | 100%
src/indium/invisibles.py | (no function) | 11 | 0 | 0 | 100%
src/indium/segments.py | _get_break_property | 5 | 1 | 0 | 80%
src/indium/segments.py | safe_truncate | 11 | 0 | 0 | 100%
src/indium/segments.py | count_graphemes | 7 | 0 | 0 | 100%
src/indium/segments.py | grapheme_slice | 20 | 0 | 0 | 100%
src/indium/segments.py | iter_graphemes | 5 | 0 | 0 | 100%
src/indium/segments.py | _find_grapheme_end | 6 | 1 | 0 | 83%
src/indium/segments.py | _is_grapheme_boundary | 68 | 0 | 0 | 100%
src/indium/segments.py | (no function) | 13 | 0 | 0 | 100%
src/indium/spoofing.py | skeleton | 7 | 0 | 0 | 100%
src/indium/spoofing.py | is_mixed_script | 15 | 0 | 0 | 100%
src/indium/spoofing.py | get_script_blocks | 13 | 0 | 0 | 100%
src/indium/spoofing.py | detect_confusables | 10 | 0 | 0 | 100%
src/indium/spoofing.py | _get_script_name | 16 | 4 | 0 | 75%
src/indium/spoofing.py | (no function) | 11 | 0 | 0 | 100%
Total |  | 330 | 8 | 0 | 98%

No items found using the specified filter.